@@ -28,7 +28,7 @@
 (declare-function org-social-parser--get-posts-from-feed "org-social-parser" (feed))
 (declare-function org-social-parser--get-value "org-social-parser" (feed key))
 (declare-function org-social-ui-thread "org-social-ui-thread" (post-url))
-(declare-function org-social-ui--post-component "org-social-ui-components" (post &optional full-timeline no-truncate))
+(declare-function org-social-ui--post-component "org-social-ui-components" (post &optional full-timeline))
 (declare-function json-read-from-string "json" (string))
 (declare-function org-ctrl-c-ctrl-c "org" (&optional arg))
 (declare-function org-table-recalculate "org-table" (&optional all noalign))
@@ -800,7 +800,6 @@ If called from a group buffer, automatically adds GROUP property."
 AUTHOR-URL is the URL of the post author.
 TIMESTAMP is the timestamp of the post being reacted to."
   (interactive)
-  (require 'emojify nil t)
   (if (fboundp 'emojify-completing-read)
       (let ((selected-emoji (emojify-completing-read "Select reaction: ")))
         (when selected-emoji
@@ -869,7 +868,7 @@ Returns t if button was found and pressed, nil otherwise."
 (defun org-social-ui--view-thread ()
   "View thread for current post by pressing the Thread button."
   (interactive)
-  (unless (org-social-ui--find-and-press-button "🧵")
+  (unless (org-social-ui--find-and-press-button "🧵 Thread")
     (message "No thread button found near point")))
 
 (defun org-social-ui--view-notifications ()
@@ -880,7 +879,7 @@ Returns t if button was found and pressed, nil otherwise."
 (defun org-social-ui--view-profile ()
   "View profile for current post by pressing the Profile button."
   (interactive)
-  (unless (org-social-ui--find-and-press-button "👤")
+  (unless (org-social-ui--find-and-press-button "👤 Profile")
     (message "No profile button found near point")))
 
 (defun org-social-ui--view-groups ()
@@ -1103,16 +1102,6 @@ Each element in REPLIES-TREE is an alist with \\='post, \\='children, and \\='mo
                                                 (append children nil)
                                               children))))))
 
-(defun org-social-ui--switch-to-timeline ()
-  "Switch to timeline buffer if it exists, otherwise load timeline."
-  (interactive)
-  (let ((timeline-buffer (get-buffer org-social-ui--timeline-buffer-name)))
-    (if timeline-buffer
-        ;; Buffer exists, just switch to it
-        (switch-to-buffer timeline-buffer)
-      ;; Buffer doesn't exist, load timeline
-      (org-social-ui-timeline))))
-
 (defun org-social-ui--thread-go-back ()
   "Go back to previous thread level or timeline and kill current buffer."
   (interactive)
@@ -1132,7 +1121,7 @@ Each element in REPLIES-TREE is an alist with \\='post, \\='children, and \\='mo
       ;; If at top level, go back to timeline and clear stack
       (setq org-social-ui--thread-stack nil)
       (setq org-social-ui--thread-level 0)
-      (org-social-ui--switch-to-timeline))
+      (org-social-ui-timeline))
     ;; Always kill the buffer we came from
     (when (buffer-live-p current-buffer)
       (kill-buffer current-buffer))))
