@@ -1,7 +1,7 @@
 ;;; org-social.el --- An Org-social client -*- lexical-binding: t -*- -*- coding: utf-8 -*-
 ;; Author: Andros Fenollosa <hi@andros.dev>
-;; Package-Version: 20251117.1026
-;; Package-Revision: 4fd0c19977e1
+;; Package-Version: 20251124.950
+;; Package-Revision: bdc0e7918abd
 ;; URL: https://github.com/tanrax/org-social.el
 ;; Package-Requires: ((emacs "30.1") (org "9.0") (request "0.3.0") (seq "2.20") (emojify "1.2"))
 ;; SPDX-License-Identifier: GPL-3.0
@@ -46,6 +46,7 @@
 (declare-function org-social-file--open "org-social-file" ())
 (declare-function org-social-file--new-post "org-social-file" (reply-url reply-id))
 (declare-function org-social-file--new-poll "org-social-file" ())
+(declare-function org-social-file--new-migration "org-social-file" ())
 (declare-function org-social-ui-timeline "org-social-ui" ())
 (declare-function org-social-validator-validate-buffer "org-social-validator" ())
 (declare-function org-social-validator-validate-and-display "org-social-validator" ())
@@ -191,6 +192,13 @@ If REPLY-URL and REPLY-ID are provided, create a reply post."
   (org-social--ensure-loaded)
   (org-social-file--new-poll))
 
+;;;###autoload
+(defun org-social-new-migration ()
+  "Create a new migration post in your Org-social feed."
+  (interactive)
+  (org-social--ensure-loaded)
+  (org-social-file--new-migration))
+
 ;;;###autoload
 (defun org-social-check-relay-mentions ()
   "Check and display mentions from the relay server."
